from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.conf import settings

PER_PAGE = getattr(settings, 'PER_PAGE', 10)

class NextPleasePaginator (Paginator):
  def __init__ (self, request, object_list, per_page, page_param='page', orphans=0, allow_empty_first_page=True):
    self.request = request
    self.page_param = page_param
    
    super(NextPleasePaginator, self).__init__ (object_list, per_page, orphans=orphans, allow_empty_first_page=allow_empty_first_page)
    
  def current (self):
    if not hasattr(self, '_current'):
      page = self.request.REQUEST.get(self.page_param, '1')
      
      try:
        self._current = self.page(page)
        
      except PageNotAnInteger:
        self._current = self.page(1)
        
      except EmptyPage:
        self._current = self.page(paginator.num_pages)
        
    return self._current
    
  def current_list (self):
    return self.current().object_list
    
  def number (self):
    return self.current().number
    
  def has_previous (self):
    return self.current().has_previous()
    
  def has_next (self):
    return self.current().has_next()
    
  def previous_qs (self):
    qs = self.request.META['QUERY_STRING']
    cs = '%s=%d' % (self.page_param, self.number())
    if self.has_previous():
      ps = '%s=%d' % (self.page_param, self.number() - 1)
      if qs:
        if cs in qs:
          qs = qs.replace(cs, ps)
          
        else:
          qs = qs + '&' + ps
          
      else:
        qs = ps
        
    return qs
    
  def next_qs (self):
    qs = self.request.META['QUERY_STRING']
    cs = '%s=%d' % (self.page_param, self.number())
    if self.has_next():
      ps = '%s=%d' % (self.page_param, self.number() + 1)
      
      if qs:
        if cs in qs:
          qs = qs.replace(cs, ps)
          
        else:
          qs = qs + '&' + ps
          
      else:
        qs = ps
        
    return qs
    
def pagination (object_list_var, per_page=PER_PAGE, page_param='page', output_var='paginator', orphans=0, allow_empty_first_page=True):
  def decorator(target):
    def wrapper(*args, **kwargs):
      tpl_response = target(*args, **kwargs)
      tpl_response.context_data[output_var] = NextPleasePaginator(
        args[0],
        tpl_response.context_data[object_list_var],
        per_page,
        page_param,
        orphans,
        allow_empty_first_page
      )
      
      return tpl_response
      
    return wrapper
    
  return decorator
  


from django import template
from django.db import models

register = template.Library()

from ..models import Blurb

@register.filter
def get_blurb (bkey):
  try:
    b = Blurb.objects.get(slug=bkey)
    
  except models.ObjectDoesNotExist:
    return None
    
  else:
    if b.content:
      return b.content
      
    return None
    


from django.template.response import TemplateResponse
from django.shortcuts import get_object_or_404
from django import http

from pizza.pagination import pagination

from .models import Blog, Post, Category

@pagination('posts')
def blog_index (request, slug=None, category=None):
  blog = get_object_or_404(Blog, slug=slug, sites__id=request.pizza_site['id'])
  if category is not None:
    category = get_object_or_404(Category, slug=category)
    
  templates = ('blog/index.html', 'pizza/blog/index.html')
  mt = 'text/html'
  
  fmt = request.GET.get('format', '')
  if fmt == 'atom':
    templates = ('blog/index.atom.xml', 'pizza/blog/index.atom.xml')
    mt = 'application/atom+xml'
    
  elif fmt == 'rss':
    templates = ('blog/index.rss.xml', 'pizza/blog/index.rss.xml')
    mt = 'application/rss+xml'
    
  c = {
    'blog': blog,
    'posts': blog.published(category),
    'category': category,
  }
  return TemplateResponse(request, templates, c, mimetype=mt)
  
def blog_detail (request, blog=None, slug=None, post=None):
  blog = get_object_or_404(Blog, slug=blog)
  query = blog.published().filter(id=post)
  if query.count() == 0:
    raise http.Http404
    
  c = {
    'blog': blog,
    'post': query[0]
  }
  return TemplateResponse(request, ('blog/detail.html', 'pizza/blog/detail.html'), c)
  


import re
import urlparse
import urllib

from django import http
from django.conf import settings
from django.contrib.sites.models import Site
from django.core.cache import cache

PIZZA_SITES_KEY = getattr(settings, 'PIZZA_SITES_KEY', 'PIZZA_SITES')
PIZZA_DEFAULT_SITE_KEY = getattr(settings, 'PIZZA_DEFAULT_SITE_KEY', 'PIZZA_DEFAULT_SITE')

class Siteware (object):
  def process_request (self, request):
    request.pizza_site = self.default_site()
    
    for s in self.get_sites():
      if re.search(s['domain'], request.get_host(), re.I):
        request.pizza_site = s
        
    return None
    
  def get_sites (self):
    ret = cache.get(PIZZA_SITES_KEY)
    if ret is None:
      ret = Site.objects.all().values()
      cache.set(PIZZA_SITES_KEY, ret)
      
    return ret
    
  def default_site (self):
    ret = cache.get(PIZZA_DEFAULT_SITE_KEY)
    if ret is None:
      ret = Site.objects.filter(id=settings.SITE_ID).values()[0]
      cache.set(PIZZA_DEFAULT_SITE_KEY, ret)
      
    return ret
    
class RememberAdminQuery:
  def process_request (self, request):
    if request.method == 'GET' and request.path.startswith('/admin'):
      other = re.search("^/admin/(\S+?)/(\S+?)/\S+$", request.path)
      found = re.search("^/admin/(\S+?)/(\S+?)/$", request.path)
      clear = request.REQUEST.get('__clearqs', '')
      pop = request.REQUEST.get('pop', '0')
      
      if not other and found:
        key = 'aquery-%s-%s-%s' % (pop, found.group(1), found.group(2))
        
        if clear == '1':
          try:
            del request.session[key]
            
          except:
            pass
            
          if pop == '1':
            url = request.path + '?pop=1'
            t = request.REQUEST.get('t', '')
            if t:
              url += '&t=' + urllib.quote(t)
              
            return http.HttpResponseRedirect(url)
            
          return http.HttpResponseRedirect(request.path)
          
        qsdict = urlparse.parse_qs(request.META['QUERY_STRING'])
        for k in ('t', 'pop'):
          try:
            del qsdict[k]
            
          except:
            pass
            
        if len(qsdict.keys()) > 0:
          request.session[key] = request.META['QUERY_STRING']
          
        else:
          try:
            qs = request.session[key]
            
          except:
            pass
            
          else:
            if qs != request.META['QUERY_STRING']:
              return http.HttpResponseRedirect('%s?%s' % (request.path, qs))
              
    return None
    


from django.db import models
from django.contrib.sites.models import Site

from pizza.kitchen_sink.models import SitesMixin, SlideshowMixin
from pizza.utils import now

class Blog (SitesMixin, models.Model):
  title = models.CharField(max_length=255)
  slug = models.SlugField(unique=True, max_length=200)
  description = models.TextField()
  
  authors = models.ManyToManyField('kitchen_sink.Author', blank=True, null=True)
  
  sites = models.ManyToManyField(Site, blank=True, null=True)
  
  def published (self, category=None):
    if category:
      return self.post_set.filter(publish__lte=now(), categories=category)
      
    return self.post_set.filter(publish__lte=now())
    
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains")
    
  def __unicode__ (self):
    return self.title
    
  class Meta:
    ordering = ('title',)
    
class Category (models.Model):
  title = models.CharField(max_length=100)
  slug = models.SlugField(unique=True, max_length=200)
  
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains")
    
  class Meta:
    ordering = ('slug',)
    verbose_name_plural = 'Categories'
    
  def __unicode__ (self):
    return self.title
    
class Post (SlideshowMixin, models.Model):
  blog = models.ForeignKey(Blog)
  
  title = models.CharField(max_length=255)
  slug = models.SlugField(unique=True, max_length=200)
  author = models.ForeignKey('kitchen_sink.Author')
  publish = models.DateTimeField()
  categories = models.ManyToManyField(Category, blank=True, null=True)
  
  body = models.TextField()
  
  image = models.ForeignKey('kitchen_sink.Image', blank=True, null=True)
  imageset = models.ForeignKey('kitchen_sink.ImageSet', blank=True, null=True)
  
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains", "slug__icontains")
    
  class Meta:
    ordering = ('-publish',)
    
  def __unicode__ (self):
    return self.title
    
  def Categories (self):
    ret = ''
    for c in self.categories.all():
      ret += c.title + ', '
      
    if ret:
      return ret[:-2]
      
    return ret
    
  def related (self, num=5):
    cats = self.categories.all()
    return Post.objects.filter(categories__in=cats).exclude(id=self.id).distinct()[:num]
    


from django.contrib import admin
from django.db import models

from pizza.kitchen_sink.widgets import RichText
from pizza.kitchen_sink.admin import AdminMixin

from .models import Blog, Category, Post

class BlogAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'slug', '_sites')
  search_fields = ('title', 'slug')
  list_filter = ('sites',)
  filter_horizontal = ('sites', 'authors')
  
class CategoryAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'slug')
  search_fields = ('title', 'slug')
  
class PostAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'publish', 'slug', 'blog', 'Categories')
  search_fields = ('title', 'slug', 'blog')
  list_filter = ('blog', 'categories')
  date_hierarchy = 'publish'
  
  filter_horizontal = ('categories',)
  
  raw_id_fields = ('blog', 'author', 'image', 'imageset')
  autocomplete_lookup_fields = {
    'fk': ['blog', 'author', 'image', 'imageset'],
  }
  
  formfield_overrides = {
    models.TextField: {'widget': RichText},
  }
  
admin.site.register(Post, PostAdmin)
admin.site.register(Category, CategoryAdmin)
admin.site.register(Blog, BlogAdmin)



import datetime
import hashlib

from django.conf import settings
from django.core.cache import cache
from django.utils.timezone import utc

PIZZA_CACHE_TIMEOUT = getattr(settings, 'PIZZA_CACHE_TIMEOUT', 600)

def now ():
  return datetime.datetime.utcnow().replace(tzinfo=utc)
  
def post_render (response, key, timeout):
  cache.set(key, response, timeout)
  
def generate_cache_key (request):
  unhashed = None
  
  if request.method != 'POST':
    unhashed = request.method + request.build_absolute_uri()
    if hasattr(request, 'pizza_site') and request.pizza_site:
      unhashed += str(request.pizza_site['id'])
      
  return unhashed
  
def pizza_cache (timeout=PIZZA_CACHE_TIMEOUT, key_generator=generate_cache_key):
  def decorator (target):
    def wrapper (*args, **kwargs):
      request = args[0]
      key = key_generator(request)
      if key:
        key = hashlib.sha1(key).hexdigest()
        
      preview = request.REQUEST.get('preview', '')
      version = request.REQUEST.get('version', '')
      
      if key is None:
        response = target(*args, **kwargs)
        
      elif (preview == '1' or version != '') and request.user.is_authenticated() and request.user.is_staff:
        response = target(*args, **kwargs)
        if preview == '1':
          cache.delete(key)
          
      else:
        response = cache.get(key, None)
        if response:
          pass
          
        else:
          response = target(*args, **kwargs)
          if hasattr(response, 'add_post_render_callback'):
            response.add_post_render_callback(lambda r: post_render(r, key, timeout))
            
          else:
            cache.set(key, response, timeout)
            
      return response
      
    return wrapper
    
  if type(timeout) == type(decorator):
    t = timeout
    timeout = PIZZA_CACHE_TIMEOUT
    return decorator(t)
    
  return decorator
  
def cached_method (target):
  def wrapper(*args, **kwargs):
    obj = args[0]
    name = '_' + target.__name__
    
    if not hasattr(obj, name):
      value = target(*args, **kwargs)
      setattr(obj, name, value)
      
    return getattr(obj, name)
    
  return wrapper
  


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Removing M2M table for field blogs on 'Category'
        db.delete_table('blog_category_blogs')


    def backwards(self, orm):
        # Adding M2M table for field blogs on 'Category'
        db.create_table('blog_category_blogs', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('category', models.ForeignKey(orm['blog.category'], null=False)),
            ('blog', models.ForeignKey(orm['blog.blog'], null=False))
        ))
        db.create_unique('blog_category_blogs', ['category_id', 'blog_id'])


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'blog.blog': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Blog'},
            'authors': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['kitchen_sink.Author']", 'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['sites.Site']", 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'blog.category': {
            'Meta': {'ordering': "('slug',)", 'object_name': 'Category'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'blog.post': {
            'Meta': {'ordering': "('-publish',)", 'object_name': 'Post'},
            'author': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['kitchen_sink.Author']"}),
            'blog': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['blog.Blog']"}),
            'body': ('django.db.models.fields.TextField', [], {}),
            'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['blog.Category']", 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'publish': ('django.db.models.fields.DateTimeField', [], {}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'kitchen_sink.author': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Author'},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['kitchen_sink.Image']", 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': "orm['sites.Site']", 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'})
        },
        'kitchen_sink.image': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Image'},
            'added_by': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}),
            'file': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modified': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['blog']


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Blurb'
        db.create_table(u'kitchen_sink_blurb', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=50)),
            ('etype', self.gf('django.db.models.fields.CharField')(max_length=25)),
            ('content', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'kitchen_sink', ['Blurb'])

        # Adding model 'File'
        db.create_table(u'kitchen_sink_file', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('file', self.gf('django.db.models.fields.files.FileField')(max_length=100)),
        ))
        db.send_create_signal(u'kitchen_sink', ['File'])

        # Adding model 'Image'
        db.create_table(u'kitchen_sink_image', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('file', self.gf('django.db.models.fields.files.ImageField')(max_length=100)),
            ('caption', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('caption_url', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('credit', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('credit_url', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
        ))
        db.send_create_signal(u'kitchen_sink', ['Image'])

        # Adding model 'ImageSet'
        db.create_table(u'kitchen_sink_imageset', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('captype', self.gf('django.db.models.fields.CharField')(default='override', max_length=10)),
        ))
        db.send_create_signal(u'kitchen_sink', ['ImageSet'])

        # Adding model 'ImageSetItem'
        db.create_table(u'kitchen_sink_imagesetitem', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('image', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['kitchen_sink.Image'])),
            ('imageset', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['kitchen_sink.ImageSet'])),
            ('caption', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('caption_url', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('credit', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('credit_url', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('sorder', self.gf('django.db.models.fields.IntegerField')()),
        ))
        db.send_create_signal(u'kitchen_sink', ['ImageSetItem'])

        # Adding model 'Author'
        db.create_table(u'kitchen_sink_author', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('slug', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=200)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=75, null=True, blank=True)),
            ('image', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['kitchen_sink.Image'], null=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'kitchen_sink', ['Author'])

        # Adding M2M table for field sites on 'Author'
        m2m_table_name = db.shorten_name(u'kitchen_sink_author_sites')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('author', models.ForeignKey(orm[u'kitchen_sink.author'], null=False)),
            ('site', models.ForeignKey(orm[u'sites.site'], null=False))
        ))
        db.create_unique(m2m_table_name, ['author_id', 'site_id'])

        # Adding model 'Page'
        db.create_table(u'kitchen_sink_page', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('url', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('tpl', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal(u'kitchen_sink', ['Page'])

        # Adding M2M table for field sites on 'Page'
        m2m_table_name = db.shorten_name(u'kitchen_sink_page_sites')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('page', models.ForeignKey(orm[u'kitchen_sink.page'], null=False)),
            ('site', models.ForeignKey(orm[u'sites.site'], null=False))
        ))
        db.create_unique(m2m_table_name, ['page_id', 'site_id'])

        # Adding model 'Redirect'
        db.create_table(u'kitchen_sink_redirect', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('url', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('goto', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal(u'kitchen_sink', ['Redirect'])

        # Adding M2M table for field sites on 'Redirect'
        m2m_table_name = db.shorten_name(u'kitchen_sink_redirect_sites')
        db.create_table(m2m_table_name, (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('redirect', models.ForeignKey(orm[u'kitchen_sink.redirect'], null=False)),
            ('site', models.ForeignKey(orm[u'sites.site'], null=False))
        ))
        db.create_unique(m2m_table_name, ['redirect_id', 'site_id'])

        # Adding model 'Version'
        db.create_table(u'kitchen_sink_version', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('page', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['kitchen_sink.Page'])),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('keywords', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('desc', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
            ('publish', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('content', self.gf('django.db.models.fields.TextField')()),
        ))
        db.send_create_signal(u'kitchen_sink', ['Version'])


    def backwards(self, orm):
        # Deleting model 'Blurb'
        db.delete_table(u'kitchen_sink_blurb')

        # Deleting model 'File'
        db.delete_table(u'kitchen_sink_file')

        # Deleting model 'Image'
        db.delete_table(u'kitchen_sink_image')

        # Deleting model 'ImageSet'
        db.delete_table(u'kitchen_sink_imageset')

        # Deleting model 'ImageSetItem'
        db.delete_table(u'kitchen_sink_imagesetitem')

        # Deleting model 'Author'
        db.delete_table(u'kitchen_sink_author')

        # Removing M2M table for field sites on 'Author'
        db.delete_table(db.shorten_name(u'kitchen_sink_author_sites'))

        # Deleting model 'Page'
        db.delete_table(u'kitchen_sink_page')

        # Removing M2M table for field sites on 'Page'
        db.delete_table(db.shorten_name(u'kitchen_sink_page_sites'))

        # Deleting model 'Redirect'
        db.delete_table(u'kitchen_sink_redirect')

        # Removing M2M table for field sites on 'Redirect'
        db.delete_table(db.shorten_name(u'kitchen_sink_redirect_sites'))

        # Deleting model 'Version'
        db.delete_table(u'kitchen_sink_version')


    models = {
        u'kitchen_sink.author': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Author'},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Image']", 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['sites.Site']", 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'})
        },
        u'kitchen_sink.blurb': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Blurb'},
            'content': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'etype': ('django.db.models.fields.CharField', [], {'max_length': '25'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.file': {
            'Meta': {'ordering': "('title',)", 'object_name': 'File'},
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.image': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Image'},
            'caption': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'caption_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'file': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.imageset': {
            'Meta': {'ordering': "('title',)", 'object_name': 'ImageSet'},
            'captype': ('django.db.models.fields.CharField', [], {'default': "'override'", 'max_length': '10'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.imagesetitem': {
            'Meta': {'ordering': "('sorder',)", 'object_name': 'ImageSetItem'},
            'caption': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'caption_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Image']"}),
            'imageset': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.ImageSet']"}),
            'sorder': ('django.db.models.fields.IntegerField', [], {})
        },
        u'kitchen_sink.page': {
            'Meta': {'ordering': "('url',)", 'object_name': 'Page'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['sites.Site']", 'symmetrical': 'False'}),
            'tpl': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.redirect': {
            'Meta': {'ordering': "('url',)", 'object_name': 'Redirect'},
            'goto': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['sites.Site']", 'symmetrical': 'False'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.version': {
            'Meta': {'ordering': "('-publish', 'id')", 'object_name': 'Version'},
            'content': ('django.db.models.fields.TextField', [], {}),
            'desc': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'keywords': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'page': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Page']"}),
            'publish': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['kitchen_sink']


from django.contrib import admin
from django.db import models
from django import forms
from django.conf import settings
from django.template.response import TemplateResponse
from django.contrib.sites.models import Site
from django.contrib.admin.widgets import ForeignKeyRawIdWidget
from django.db.models.fields.related import ManyToOneRel
from django.contrib.admin.util import unquote
from django.contrib.admin import helpers

from .widgets import RichText
from .models import Page, Version, Redirect, Image, File, Blurb, Author, \
                    ImageSet, ImageSetItem, EDITORTYPES

ADMIN_QUERY_JS = (
  'ks/js/jquery-1.8.0.min.js',
  'ks/js/clear_filters.js',
)

class AdminMixin (object):
  class Media:
    js = ADMIN_QUERY_JS
    
class AuthorAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('name', 'slug', 'Thumbnail', '_sites')
  search_fields = ('name', 'slug', 'description')
  raw_id_fields = ('image',)
  filter_horizontal = ('sites',)
  autocomplete_lookup_fields = {
    'fk': ['image'],
  }
  
  formfield_overrides = {
    models.TextField: {'widget': RichText},
  }
  
class ReAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('url', 'goto', '_sites')
  list_filter = ('sites',)
  search_fields = ('url', 'goto')
  filter_horizontal = ('sites',)
  
class PageAdmin (admin.ModelAdmin):
  list_display = ('url', 'tpl', '_sites', 'Settings', 'View_Published', 'Versions')
  list_filter = ('sites', 'tpl')
  search_fields = ('url',)
  filter_horizontal = ('sites',)
  
  class Media:
    css = {'all': ('ks/css/admin.css', )}
    js = (
      'ks/js/jquery-1.8.0.min.js',
      'ks/js/ks.js',
      'ks/js/clear_filters.js',
    )
    
  def get_form (self, request, obj=None, **kwargs):
    if obj and obj.__class__.__name__ == 'Version':
      return obj.page.admin_form(obj)
      
    return super(PageAdmin, self).get_form(request, obj=obj, **kwargs)
    
  def get_object (self, request, object_id):
    if request.path.endswith('/delete/'):
      return super(PageAdmin, self).get_object(request, object_id)
      
    if request.GET.get('settings', '') != '1':
      ver = request.GET.get('version', '')
      page = super(PageAdmin, self).get_object(request, object_id)
      if ver:
        ret = page.version_set.get(id=ver)
        ret.publish = None
        return ret
        
      qs = page.version_set.filter(publish__isnull=True)
      if qs.count() > 0:
        return qs[0]
        
      else:
        qs = page.version_set.all()
        if qs.count() > 0:
          obj = Version(
            page=qs[0].page,
            title=qs[0].title,
            keywords=qs[0].keywords,
            desc=qs[0].desc,
            content=qs[0].content
          )
          return obj
          
      return Version(page=page)
      
    return super(PageAdmin, self).get_object(request, object_id)
    
  def response_change (self, request, obj):
    if obj and obj.__class__.__name__ == 'Version':
      obj = obj.page
      
    return super(PageAdmin, self).response_change(request, obj)
    
  def get_urls (self):
    from django.conf.urls import patterns, url
    
    info = self.model._meta.app_label, self.model._meta.module_name
    urlpatterns = patterns('', url(r'^(.+)/versions/$', self.versionlist_view, name='%s_%s_versionlist' % info),)
    urlpatterns += super(PageAdmin, self).get_urls()
    
    return urlpatterns
    
  def versionlist_view (self, request, object_id):
    if not self.has_change_permission(request, None):
      raise PermissionDenied
      
    obj = self.get_object(request, object_id)
    return TemplateResponse(request, 'ks/admin_versions.html', {'page': obj.page})
    
  def save_model (self, request, obj, form, change):
    if obj and obj.__class__.__name__ == 'Version':
      cdict = {}
      for key in form.cleaned_data.keys():
        if key.startswith('generatedfield_'):
          if hasattr(form.cleaned_data[key], 'id'):
            cdict[key[15:]] = form.cleaned_data[key].id
            
          else:
            cdict[key[15:]] = form.cleaned_data[key]
            
      obj.set_content(cdict)
      request.obj = obj
      
    return super(PageAdmin, self).save_model(request, obj, form, change)
    
  def save_formset (self, request, form, formset, change):
    for f in formset:
      key = f.inline
      break
      
    cdict = request.obj.get_content()
    cdict[key] = []
    instances = formset.save(commit=False)
    for inline in instances:
      d = {}
      for ikey, value in inline.cleaned_data.items():
        if ikey.startswith('generatedfield_'):
          if hasattr(value, 'id'):
            d[ikey[15:]] = value.id
            
          else:
            d[ikey[15:]] = value
            
      cdict[key].append(d)
      
    request.obj.set_content(cdict)
    request.obj.save()
    
  def get_inline_instances (self, request, obj=None):
    inline_instances = []
    if obj and hasattr(obj, 'page'):
      for inline_class in obj.page.inlines(obj):
        inline = inline_class(self.model, self.admin_site)
        inline_instances.append(inline)
        
    return inline_instances
    
  def change_view (self, request, object_id, form_url='', extra_context=None):
    ret = super(PageAdmin, self).change_view(request, object_id, form_url=form_url, extra_context=extra_context)
    if request.method == 'GET' and isinstance(ret, TemplateResponse):
      if not ret.is_rendered:
        obj = self.get_object(request, unquote(object_id))
        ret.context_data['inline_admin_formsets'] = self.regenerate_inlines(request, obj)
        
    return ret
    
  def regenerate_inlines (self, request, obj):
    ModelForm = self.get_form(request, obj)
    formsets = []
    form = ModelForm(instance=obj)
    inline_instances = self.get_inline_instances(request, obj)
    prefixes = {}
    for FormSet, inline in zip(self.get_formsets(request, obj), inline_instances):
      prefix = FormSet.get_default_prefix()
      prefixes[prefix] = prefixes.get(prefix, 0) + 1
      if prefixes[prefix] != 1 or not prefix:
        prefix = "%s-%s" % (prefix, prefixes[prefix])
        
      formset = FormSet(instance=obj, prefix=prefix, initial=inline.initial)
      formsets.append(formset)
      
    inline_admin_formsets = []
    for inline, formset in zip(inline_instances, formsets):
      fieldsets = list(inline.get_fieldsets(request, obj))
      readonly = list(inline.get_readonly_fields(request, obj))
      prepopulated = dict(inline.get_prepopulated_fields(request))
      
      inline_admin_formset = helpers.InlineAdminFormSet(inline, formset,
          fieldsets, prepopulated, readonly, model_admin=self)
          
      inline_admin_formsets.append(inline_admin_formset)
      
    return inline_admin_formsets
    
class ImageAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'file', 'Thumbnail', 'view')
  search_fields = ('title', 'file')
  
class ImageSetItemInline (admin.StackedInline):
  model = ImageSetItem
  raw_id_fields = ('image',)
  autocomplete_lookup_fields = {
    'fk': ['image'],
  }
  
  fields = ('image', 'caption', 'caption_url', 'credit', 'credit_url', 'sorder')
  if 'grappelli' in settings.INSTALLED_APPS:
    sortable_field_name = "sorder"
    
    formfield_overrides = {
      models.IntegerField: {'widget': forms.HiddenInput},
    }
    
class ImageSetAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'Thumbnails')
  search_fields = ('title',)
  inlines = (ImageSetItemInline,)
  
class FileAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'file')
  search_fields = ('title', 'file')
  
class BlurbAdmin (AdminMixin, admin.ModelAdmin):
  list_display = ('title', 'slug', 'etype', 'Settings')
  search_fields = ('title', 'slug')
  list_filter = ('etype',)
  #formfield_overrides = {
  #  models.TextField: {'widget': RichText},
  #}
  
  def form_field (self, etype, initial=None):
    if etype == 'image':
      return forms.ModelChoiceField(
        queryset=Image.objects.all(),
        required=False, label='Content',
        widget=ForeignKeyRawIdWidget(ManyToOneRel(Image, 'id'), admin.site),
        initial=initial
      )
      
    elif etype == 'rich':
      return forms.CharField(required=False, label='Content', widget=RichText, initial=initial)
      
    elif etype == 'plain':
      return forms.CharField(required=False, label='Content', widget=forms.Textarea, initial=initial)
      
    return forms.CharField(max_length=255, required=False, label='Content', initial=initial, widget=forms.TextInput(attrs={'class': 'vTextField'}))
    
  def edit_form (self, obj):
    class Meta:
      model = Blurb
      fields = ('title', 'content')
      
    fields = {
      'title': forms.CharField(max_length=255, widget=forms.TextInput(attrs={'class': 'vTextField', 'readonly': 'readonly'})),
      'content': self.form_field(obj.etype),
      
      'Meta': Meta
    }
    return type('AdminForm', (forms.ModelForm,), fields)
    
  def setting_form (self):
    class Meta:
      model = Blurb
      fields = ('title', 'slug', 'etype')
      
    fields = {
      'title': forms.CharField(max_length=255, widget=forms.TextInput(attrs={'class': 'vTextField'})),
      'slug': forms.SlugField(widget=forms.TextInput(attrs={'class': 'vTextField'})),
      'etype': forms.ChoiceField(label="Content Type", choices=EDITORTYPES),
      
      'Meta': Meta
    }
    return type('AdminForm', (forms.ModelForm,), fields)
    
  def get_form (self, request, obj=None, **kwargs):
    if obj is None or request.GET.get('settings', '') == '1':
      return self.setting_form()
      
    return self.edit_form(obj)
    
admin.site.register(Author, AuthorAdmin)
admin.site.register(Redirect, ReAdmin)
admin.site.register(Page, PageAdmin)
admin.site.register(Image, ImageAdmin)
admin.site.register(ImageSet, ImageSetAdmin)
admin.site.register(File, FileAdmin)
admin.site.register(Blurb, BlurbAdmin)




import json

from django import http
from django.template.response import TemplateResponse
from django.contrib.admin.views.decorators import staff_member_required
from django.views.decorators.csrf import csrf_exempt
from django.views.decorators.http import require_POST
from django.core.urlresolvers import resolve

from sorl.thumbnail import get_thumbnail

from .models import Page, Redirect, Image
from pizza.utils import pizza_cache

@pizza_cache
def page (request):
  version = request.GET.get('version', '')
  
  qs = Redirect.objects.filter(url=request.path, sites__id=request.pizza_site['id'])
  if qs.count() > 0:
    return http.HttpResponseRedirect(qs[0].goto)
    
  qs = Page.objects.filter(url=request.path, sites__id=request.pizza_site['id'])
  if qs.count() > 0:
    if version and request.user.is_authenticated():
      pubver = qs[0].published_version(version)
      
    else:
      pubver = qs[0].published_version()
      
    if pubver:
      context = pubver.get_context()
      
      c = {
        'page': qs[0],
        'title': pubver.title,
        'keywords': pubver.keywords,
        'description': pubver.desc
      }
      
      c.update(context)
      return TemplateResponse(request, qs[0].tpl, c)
      
  if not request.path.endswith('/'):
    match = resolve(request.path + '/')
    if match.url_name != 'pizza.utils.wrapper':
      url = request.path + '/'
      if request.META['QUERY_STRING']:
        url += '?' + request.META['QUERY_STRING']
        
      return http.HttpResponseRedirect(url)
      
  raise http.Http404
  
@staff_member_required
def admin_image_list (request):
  images = []
  
  for obj in Image.objects.all().order_by("-modified")[:100]:
    im = get_thumbnail(obj.file, '75x75', crop='center')
    images.append({"thumb": im.url, "image": obj.file.url})
    
  return http.HttpResponse(json.dumps(images), mimetype="application/json")
  
@csrf_exempt
@require_POST
@staff_member_required
def admin_image_upload (request):
  images = []
  for f in request.FILES.getlist("file"):
    obj = Image.objects.create(file=f, title=f.name, added_by=request.user)
    images.append({"filelink": obj.file.url})
    
  return http.HttpResponse(json.dumps(images), mimetype="application/json")
  
@staff_member_required
def admin_editon (request):
  goto = request.GET.get('goto', '')
  response = http.HttpResponseRedirect(goto)
  
  response.set_cookie('PIZZA_EDIT', value='ON', max_age=60 * 60 * 24, httponly=False)
  return response
  


from django import forms
from django.conf import settings
from django.utils.safestring import mark_safe
from django.core.urlresolvers import reverse

class RichText (forms.Textarea):
  def render (self, name, value, attrs=None):
    ret = super(RichText, self).render(name, value, attrs=attrs)
    ret += """
    <script type="text/javascript">
      CKEDITOR.replace( \'id_%s\', {customConfig : \'%sks/js/ckconfig.js\'});
    </script>
    """ % (
      name,
      settings.STATIC_URL
    )
    
    return mark_safe(ret)
    
  class Media:
    #css = {'all': ('ks/redactor/redactor.css', 'ks/redactor/admin.css')}
    js = (
      'ks/ckeditor/ckeditor.js',
    )
    


import sys

from setuptools import setup, find_packages

setup(
    name = "Django-Pizza",
    version = '13.10.3',
    description = "Yet another Django CMS.",
    url = "https://github.com/pizzapanther/Django-Pizza",
    author = "Paul Bailey",
    author_email = "paul.m.bailey@gmail.com",
    license = "BSD",
    packages = [
      'pizza',
      'pizza.kitchen_sink',
      'pizza.kitchen_sink.migrations',
      'pizza.kitchen_sink.templatetags',
      'pizza.blog',
      'pizza.blog.migrations',
      'pizza.pagination',
    ],
    include_package_data = True,
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    install_requires = [
      "sorl-thumbnail>=11.01"
    ]
)



from django.conf.urls import patterns, url, include

urlpatterns = patterns('',
  url(r'^admin_editon/$', 'pizza.kitchen_sink.views.admin_editon', name='admin_editon'),
  
  url(r'^admin_image_list/$', 'pizza.kitchen_sink.views.admin_image_list', name='admin_image_list'),
  url(r'^admin_image_upload/$', 'pizza.kitchen_sink.views.admin_image_upload', name='admin_image_upload'),
)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Inline'
        db.create_table(u'kitchen_sink_inline', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('page', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['kitchen_sink.Page'])),
        ))
        db.send_create_signal(u'kitchen_sink', ['Inline'])


    def backwards(self, orm):
        # Deleting model 'Inline'
        db.delete_table(u'kitchen_sink_inline')


    models = {
        u'kitchen_sink.author': {
            'Meta': {'ordering': "('name',)", 'object_name': 'Author'},
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Image']", 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'to': u"orm['sites.Site']", 'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200'})
        },
        u'kitchen_sink.blurb': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Blurb'},
            'content': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'etype': ('django.db.models.fields.CharField', [], {'max_length': '25'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '50'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.file': {
            'Meta': {'ordering': "('title',)", 'object_name': 'File'},
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.image': {
            'Meta': {'ordering': "('title',)", 'object_name': 'Image'},
            'caption': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'caption_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'file': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.imageset': {
            'Meta': {'ordering': "('title',)", 'object_name': 'ImageSet'},
            'captype': ('django.db.models.fields.CharField', [], {'default': "'override'", 'max_length': '10'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.imagesetitem': {
            'Meta': {'ordering': "('sorder',)", 'object_name': 'ImageSetItem'},
            'caption': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'caption_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'credit_url': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Image']"}),
            'imageset': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.ImageSet']"}),
            'sorder': ('django.db.models.fields.IntegerField', [], {})
        },
        u'kitchen_sink.inline': {
            'Meta': {'object_name': 'Inline'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'page': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Page']"})
        },
        u'kitchen_sink.page': {
            'Meta': {'ordering': "('url',)", 'object_name': 'Page'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['sites.Site']", 'symmetrical': 'False'}),
            'tpl': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.redirect': {
            'Meta': {'ordering': "('url',)", 'object_name': 'Redirect'},
            'goto': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'sites': ('django.db.models.fields.related.ManyToManyField', [], {'to': u"orm['sites.Site']", 'symmetrical': 'False'}),
            'url': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'kitchen_sink.version': {
            'Meta': {'ordering': "('-publish', 'id')", 'object_name': 'Version'},
            'content': ('django.db.models.fields.TextField', [], {}),
            'desc': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'keywords': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
            'page': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['kitchen_sink.Page']"}),
            'publish': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        u'sites.site': {
            'Meta': {'ordering': "('domain',)", 'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['kitchen_sink']


import datetime
import cPickle as pickle
import urllib

from django import forms
from django.db import models
from django.conf import settings
from django.contrib.sites.models import Site
from django.template.defaultfilters import date
from django.contrib.admin.widgets import AdminSplitDateTime, ForeignKeyRawIdWidget
from django.contrib import admin
from django.db.models.fields.related import ManyToOneRel
from django.utils.timezone import utc
from django.db.models.signals import post_save
from django.core.cache import cache
from django.dispatch import receiver
from django.core.urlresolvers import reverse

from .widgets import RichText
from pizza.middleware import PIZZA_SITES_KEY, PIZZA_DEFAULT_SITE_KEY
from pizza.utils import cached_method

from sorl.thumbnail import get_thumbnail

PIZZA_FILE_DIR = getattr(settings, 'PIZZA_FILE_DIR', 'pizza/files/%Y-%m')
PIZZA_IMAGE_DIR = getattr(settings, 'PIZZA_IMAGE_DIR', 'pizza/images/%Y-%m')
PIZZA_TEMPLATES = getattr(settings, 'PIZZA_TEMPLATES', {})

EDITORTYPES = (
  ('rich', 'Rich Text'),
  ('plain', 'Plain Text'),
  ('richone', 'Rich One Line Text'),
  ('plainone', 'Plain One Line Text'),
  ('image', 'Image')
)

@receiver(post_save, sender=Site)
def site_cache (sender, **kwargs):
  cache.delete(PIZZA_SITES_KEY)
  cache.delete(PIZZA_DEFAULT_SITE_KEY)
  
class SitesMixin (object):
  def _sites (self):
    ret = ''
    for s in self.sites.all():
      ret += s.name + ', '
      
    if ret:
      ret = ret[:-2]
      
    return ret
    
class SlideshowMixin (object):
  @cached_method
  def first_image (self):
    if self.imageset:
      if self.imageset.imagesetitem_set.all().count() > 0:
        return self.imageset.imagesetitem_set.all()[0].image
        
    if self.image:
      return self.image
      
    return None
    
  @cached_method
  def image_list (self):
    ret = []
    if self.imageset:
      return self.imageset.imagesetitem_set.all()
      
    elif self.image:
      ret.append(self.image)
      
    return ret
    
class ViewFileMixin (object):
  def view (self):
    return '<a href="%s" target="_blank">View File</a>' % self.file.url
    
  view.allow_tags = True
  
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains")
    
class Blurb (models.Model):
  title = models.CharField(max_length=255)
  slug = models.SlugField('Key', unique=True)
  etype = models.CharField("Editor Type", choices=EDITORTYPES, max_length=25)
  content = models.TextField(blank=True, null=True)
  
  def __unicode__ (self):
    return self.title
    
  class Meta:
    ordering = ('title',)
    
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains", "slug__icontains")
    
  def Settings (self):
    return '<a href="./%d/?settings=1">Edit Settings</a>' % self.id
    
  Settings.allow_tags = True
  
class File (ViewFileMixin, models.Model):
  title = models.CharField(max_length=255)
  file = models.FileField(upload_to=PIZZA_FILE_DIR)
  
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains", "file__icontains")
    
  def __unicode__ (self):
    return self.title
    
  class Meta:
    ordering = ("title",)
    
class Image (ViewFileMixin, models.Model):
  title = models.CharField(max_length=255)
  file = models.ImageField(upload_to=PIZZA_IMAGE_DIR)
  
  caption = models.CharField(max_length=255, blank=True, null=True)
  caption_url = models.CharField('Caption URL', max_length=255, blank=True, null=True)
  
  credit = models.CharField('Photo Credit', max_length=255, blank=True, null=True)
  credit_url = models.CharField('Photo Credit URL', max_length=255, blank=True, null=True)
  
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains", "file__icontains")
    
  def __unicode__ (self):
    return self.title
    
  class Meta:
    ordering = ("title",)
    
  def Thumbnail (self):
    im = get_thumbnail(self.file, '64x64')
    return '<img src="%s" alt="">' % im.url
    
  Thumbnail.allow_tags = True
  
  def cap (self):
    return self.caption
    
  def cap_url (self):
    return self.caption_url
    
  def cred (self):
    return self.credit
    
  def cred_url (self):
    return self.credit_url
    
CAPTYPES = (
  ('override', 'Use image captions and credits, and override if filled in below.'),
  ('mine', 'Use captions and credits from below only'),
)

class ImageSet (models.Model):
  title = models.CharField(max_length=255)
  captype = models.CharField('Caption/Credit Override', max_length=10, choices=CAPTYPES, default='override')
  
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains")
    
  def __unicode__ (self):
    return self.title
    
  class Meta:
    ordering = ("title",)
    verbose_name = 'Image Set'
    
  def Thumbnails (self):
    ret = ''
    for item in self.imagesetitem_set.all():
      ret += item.image.Thumbnail().replace('<img ', '<img style="float: left; margin: 0 10px 10px 0;" ')
      
    ret += '<div style="clear: both;"></div>'
    return ret
    
  Thumbnails.allow_tags = True
  
class ImageSetItem (models.Model):
  image = models.ForeignKey(Image)
  imageset = models.ForeignKey(ImageSet)
  
  caption = models.CharField(max_length=255, blank=True, null=True)
  caption_url = models.CharField('Caption URL', max_length=255, blank=True, null=True)
  
  credit = models.CharField('Photo Credit', max_length=255, blank=True, null=True)
  credit_url = models.CharField('Photo Credit URL', max_length=255, blank=True, null=True)
  
  sorder = models.IntegerField('Order')
  
  def __unicode__ (self):
    return str(self.sorder)
    
  class Meta:
    ordering = ("sorder",)
    
  def file (self):
    return self.image.file
    
  def cap (self):
    if self.imageset.captype == 'mine' or self.caption:
      return self.caption
      
    return self.image.caption
    
  def cap_url (self):
    if self.imageset.captype == 'mine' or self.caption_url:
      return self.caption_url
    
    return self.image.caption_url
    
  def cred (self):
    if self.imageset.captype == 'mine' or self.credit:
      return self.credit
    
    return self.image.credit
    
  def cred_url (self):
    if self.imageset.captype == 'mine' or self.credit_url:
      return self.credit_url
      
    return self.image.credit_url
    
class Author (SitesMixin, models.Model):
  name = models.CharField(max_length=255)
  slug = models.SlugField(unique=True, max_length=200)
  email = models.EmailField(blank=True, null=True)
  
  image = models.ForeignKey(Image, blank=True, null=True)
  description = models.TextField('Description/Bio', blank=True, null=True)
  
  sites = models.ManyToManyField(Site, blank=True, null=True)
  
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "name__icontains")
    
  def __unicode__ (self):
    return self.name
    
  class Meta:
    ordering = ("name",)
    
  def Thumbnail (self):
    if self.image:
      return self.image.Thumbnail()
      
    return ''
    
  Thumbnail.allow_tags = True
  
TEMPLATES = []
for key, value in PIZZA_TEMPLATES.items():
  TEMPLATES.append((key, value['name']))
  
class ModelForm (forms.ModelForm):
  def save (self, *args, **kw):
    instance = super(ModelForm, self).save(*args, **kw)
    instance.cleaned_data = self.cleaned_data
    return instance
    
class Page (SitesMixin, models.Model):
  url = models.CharField('URL', max_length=255, help_text='Examples: / = HomePage, /some_page, /some_page/sub_page')
  tpl = models.CharField("Template", choices=TEMPLATES, max_length=255)
  
  sites = models.ManyToManyField(Site)
  
  class Meta:
    ordering = ('url',)
    
  def __unicode__ (self):
    return self.url
    
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "url__icontains",)
    
  def Settings (self):
    return '<a href="./%d/?settings=1">Edit Settings</a>' % self.id
    
  Settings.allow_tags = True
  
  def published_version (self, version=None):
    now = datetime.datetime.utcnow().replace(tzinfo=utc)
    if version:
      qs = self.version_set.filter(id=version)
      
    else:
      qs = self.version_set.filter(publish__lte=now)
      
    if qs.count() > 0:
      return qs[0]
      
    return None
    
  def version_iter (self):
    ret = []
    for v in self.unpublished_versions():
      ret.append(v)
      
    for v in self.published_versions():
      ret.append(v)
      
    return ret
    
  def published_versions (self):
    return self.version_set.filter(publish__isnull=False)
    
  def unpublished_versions (self):
    return self.version_set.filter(publish__isnull=True)
    
  def form_field (self, etype, name, initial=None, req=False):
    if etype == 'image':
      return forms.ModelChoiceField(
        queryset=Image.objects.all(),
        required=req, label=name,
        widget=ForeignKeyRawIdWidget(ManyToOneRel(Image, 'id'), admin.site),
        initial=initial
      )
      
    elif etype == 'rich':
      return forms.CharField(required=req, label=name, widget=RichText, initial=initial)
      
    elif etype == 'plain':
      return forms.CharField(required=req, label=name, widget=forms.Textarea, initial=initial)
      
    return forms.CharField(max_length=255, required=req, label=name, initial=initial, widget=forms.TextInput(attrs={'class': 'vTextField'}))
    
  def admin_form (self, version, regions=None, inline=None):
    if regions and inline:
      class Meta:
        model = Version
        exclude = ('page', 'content', 'title', 'keywords', 'desc', 'publish')
        
      fields = {
        'inline': inline,
        'Meta': Meta
      }
      
    else:
      class Meta:
        model = Version
        exclude = ('page', 'content')
        
      fields = {
        'title': forms.CharField(max_length=255, widget=forms.TextInput(attrs={'class': 'vTextField'})),
        'keywords': forms.CharField(max_length=255, required=False, widget=forms.TextInput(attrs={'class': 'vTextField'})),
        'desc': forms.CharField(max_length=255, label='Description', required=False, widget=forms.TextInput(attrs={'class': 'vTextField'})),
        'publish': forms.DateTimeField(required=False, widget=AdminSplitDateTime),
        
        'Meta': Meta
      }
      
      regions = PIZZA_TEMPLATES[self.tpl]['regions']
      
    content = version.get_content()
    if inline:
      content = {}
      
    req = True
    for cvar, props in regions.items():
      initial = None
      if content.has_key(cvar):
        initial = content[cvar]
        
      fields['generatedfield_' + cvar] = self.form_field(*props, initial=initial, req=req)
      req = False
      
    if regions and inline:
      fields['DELETE'] = forms.BooleanField(label='Delete', required=False)
      
    return type('AdminForm', (ModelForm,), fields)
    
  def inlines (self, version):
    classes = []
    if 'inlines' in PIZZA_TEMPLATES[self.tpl]:
      index = 0
      for key, inline in PIZZA_TEMPLATES[self.tpl]['inlines'].items():
        iclass = admin.StackedInline
        iextra = 3
        imax_num = None
        iname = None
        iplural = None
        
        if 'type' in inline and inline['type'] == 'table':
          iclass = admin.TabularInline
          
        if 'extra' in inline:
          iextra = inline['extra']
          
        if 'max_num' in inline:
          imax_num = inline['max_num']
          
        if 'verbose_name' in inline:
          iname = inline['verbose_name']
          
        if 'verbose_name_plural' in inline:
          iplural = inline['verbose_name_plural']
          
        init = []
        content = version.get_content()
        if key in content:
          init_list = content[key]
          for init_dict in init_list:
            idict = {}
            for ikey, value in init_dict.items():
              idict['generatedfield_' + ikey] = value
              
            init.append(idict)
            
        class AdminInline (iclass):
          extra = iextra
          max_num = imax_num
          model = Inline
          verbose_name = iname
          verbose_name_plural = iplural
          form = self.admin_form(version, regions=inline['regions'], inline=key)
          initial = init
          
        classes.append(AdminInline)
        index += 1
        
    return classes
    
  def Versions (self):
    return '<div id="view_versions_%d"><a href="javascript: void(0);" onclick="get_versions(%d)">View Versions</a></div>' % (self.id, self.id)
    
  Versions.allow_tags = True
  
  def View_Published (self):
    edit_url = reverse('kitchen_sink:admin_editon')
    goto = urllib.quote('http://' + self.sites.all()[0].domain + self.url + '?preview=1')
    return '<a href="%s" target="_blank">View</a>&nbsp; -&nbsp;<a href="%s?goto=%s" target="_blank">Edit on Site</a>' % (self.url, edit_url, goto)
    
  View_Published.allow_tags = True
    
class Redirect (SitesMixin, models.Model):
  url = models.CharField('URL', max_length=255, help_text='Examples: /, /some_page, /some_page/sub_page')
  goto = models.CharField('Redirect To', max_length=255, help_text='Relative urls should begin with a slash (/), absolute urls should begin with "http://"')
  
  sites = models.ManyToManyField(Site)
  
  class Meta:
    ordering = ('url',)
    
  def __unicode__ (self):
    return self.url
    
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "url__icontains",)
    
class Version (models.Model):
  page = models.ForeignKey(Page)
  title = models.CharField(max_length=255)
  
  keywords = models.CharField(max_length=255, blank=True, null=True)
  desc = models.CharField('Description', max_length=255, blank=True, null=True)
  
  publish = models.DateTimeField(blank=True, null=True)
  
  content = models.TextField()
  
  def get_context (self):
    c = self.get_content()
    for cvar, props in PIZZA_TEMPLATES[self.page.tpl]['regions'].items():
      if props[0] == 'image' and c.has_key(cvar) and c[cvar]:
        try:
          c[cvar] = Image.objects.get(id=c[cvar])
          
        except models.ObjectDoesNotExist:
          pass
        
    return c
    
  def get_content (self):
    if self.content:
      return pickle.loads(str(self.content))
      
    return {}
    
  def set_content (self, d):
    self.content = pickle.dumps(d)
    
  class Meta:
    ordering = ('-publish', 'id')
    
  def __unicode__ (self):
    return self.page.url
    
  @staticmethod
  def autocomplete_search_fields():
    return ("id__iexact", "title__icontains",)
    
class Inline (models.Model):
  page = models.ForeignKey(Page)
  
  def save (self):
    print 'SKIPPING SAVE'
    
  class Meta:
    verbose_name = " "
    verbose_name_plural = " "
    